==> mall-center-api-0.1.13.6-20211118.054730-7-sources.jar: cn/com/duiba/mall/center/api/domain/paramquary/discount/DiscountTicketListQueryParam.java <==
package cn.com.duiba.mall.center.api.domain.paramquary.discount;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @author fja
 */
public class DiscountTicketListQueryParam implements Serializable {

    private List<Long> discountIds;
    /**
     * 1：上架、0：下架
     */
    private Integer discountStatus;

    /**
     * 1: 满减券，2：满折券
     */
    private Integer discountType;

    /**
     * 使用范围 1: 全品类，2：全品类（自有），3：全品类（兑吧），4：单品券，5：分组类
     */
    private List<Integer> discountScopes;

    /**
     * 0: 无限制，1：白名单用户
     */
    private Integer discountUserType;

    /**
     * 0：未删除、1：删除
     */
    private Integer deleted;

    /**
     * 创建时间
     */
    private Date gmtCreate;


    public List<Long> getDiscountIds() {
        return discountIds;
    }

    public void setDiscountIds(List<Long> discountIds) {
        this.discountIds = discountIds;
    }

    public Integer getDiscountStatus() {
        return discountStatus;
    }

    public void setDiscountStatus(Integer discountStatus) {
        this.discountStatus = discountStatus;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Integer getDiscountType() {
        return discountType;
    }

    public void setDiscountType(Integer discountType) {
        this.discountType = discountType;
    }

    public List<Integer> getDiscountScopes() {
        return discountScopes;
    }

    public void setDiscountScopes(List<Integer> discountScopes) {
        this.discountScopes = discountScopes;
    }

    public Integer getDiscountUserType() {
        return discountUserType;
    }

    public void setDiscountUserType(Integer discountUserType) {
        this.discountUserType = discountUserType;
    }
}

==> mall-center-api-3.6.14-sources.jar: cn/com/duiba/mall/center/api/domain/paramquary/discount/DiscountTicketListQueryParam.java <==
package cn.com.duiba.mall.center.api.domain.paramquary.discount;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @author fja
 */
public class DiscountTicketListQueryParam implements Serializable {

    private Long appId;

    private List<Long> discountIds;
    /**
     * 1：上架、0：下架
     */
    private Integer discountStatus;

    /**
     * 1: 满减券，2：满折券
     */
    private Integer discountType;

    /**
     * 使用范围 1: 全品类，2：全品类（自有），3：全品类（兑吧），4：单品券，5：分组类
     */
    private List<Integer> discountScopes;

    /**
     * 0: 无限制，1：白名单用户
     */
    private Integer discountUserType;

    /**
     * 0：未删除、1：删除
     */
    private Integer deleted;

    /**
     * 创建时间
     */
    private Date gmtCreate;
    /**
     * 0: 不可叠加，1：可叠加
     */
    private Integer combineType;
    /**
     * 1: 领取，2：推送
     */
    private Integer distributeType;

    public List<Long> getDiscountIds() {
        return discountIds;
    }

    public Integer getDiscountStatus() {
        return discountStatus;
    }

    public Integer getDiscountType() {
        return discountType;
    }

    public List<Integer> getDiscountScopes() {
        return discountScopes;
    }

    public Integer getDiscountUserType() {
        return discountUserType;
    }

    public void setDiscountIds(List<Long> discountIds) {
        this.discountIds = discountIds;
    }

    public void setDiscountStatus(Integer discountStatus) {
        this.discountStatus = discountStatus;
    }

    public void setDiscountType(Integer discountType) {
        this.discountType = discountType;
    }

    public void setDiscountScopes(List<Integer> discountScopes) {
        this.discountScopes = discountScopes;
    }

    public void setDiscountUserType(Integer discountUserType) {
        this.discountUserType = discountUserType;
    }

    public Integer getDeleted() {
        return deleted;
    }

    public void setDeleted(Integer deleted) {
        this.deleted = deleted;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Integer getCombineType() {
        return combineType;
    }

    public void setCombineType(Integer combineType) {
        this.combineType = combineType;
    }

    public Integer getDistributeType() {
        return distributeType;
    }

    public void setDistributeType(Integer distributeType) {
        this.distributeType = distributeType;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }
}
